summaryrefslogtreecommitdiffstats
path: root/src/usr/hwas/common/hwas.C
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2013-08-20 16:28:44 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-09-12 14:07:44 -0500
commit24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5 (patch)
tree942e1dbbf85a21b215238805ed600794df5f4764 /src/usr/hwas/common/hwas.C
parentd8fdb9f6399d602c3314fe8a0a6578364e886120 (diff)
downloadtalos-hostboot-24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5.tar.gz
talos-hostboot-24f7b770b42f2889e8970e75f1ecd8bc1bdb77d5.zip
GARD: errlog event ID (EID) instead of platform log id (PLID)
gard records and deconfiguredBy use event id instead of plid. Change-Id: Ic0ccbd5b83e1738839819d471956ca700cd22fff RTC: 79346 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/5853 Tested-by: Jenkins Server Reviewed-by: SHELDON R. BAILEY <baileysh@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwas/common/hwas.C')
-rw-r--r--src/usr/hwas/common/hwas.C39
1 files changed, 18 insertions, 21 deletions
diff --git a/src/usr/hwas/common/hwas.C b/src/usr/hwas/common/hwas.C
index cf0bc6185..fc6017e66 100644
--- a/src/usr/hwas/common/hwas.C
+++ b/src/usr/hwas/common/hwas.C
@@ -86,7 +86,7 @@ bool compareProcGroup(procRestrict_t t1, procRestrict_t t2)
* @param[in] i_target pointer to target that we're looking at
* @param[in] i_present boolean indicating present or not
* @param[in] i_functional boolean indicating functional or not
- * @param[in] i_errlPlid errplid that caused change to non-funcational;
+ * @param[in] i_errlEid erreid that caused change to non-funcational;
* 0 if not associated with an error or if
* functional is true
*
@@ -95,13 +95,13 @@ bool compareProcGroup(procRestrict_t t1, procRestrict_t t2)
*/
void enableHwasState(Target *i_target,
bool i_present, bool i_functional,
- uint32_t i_errlPlid)
+ uint32_t i_errlEid)
{
HwasState hwasState = i_target->getAttr<ATTR_HWAS_STATE>();
if (i_functional == false)
- { // record the PLID as a reason that we're marking non-functional
- hwasState.deconfiguredByPlid = i_errlPlid;
+ { // record the EID as a reason that we're marking non-functional
+ hwasState.deconfiguredByEid = i_errlEid;
}
hwasState.poweredOn = true;
hwasState.present = i_present;
@@ -121,7 +121,7 @@ errlHndl_t discoverTargets()
++target)
{
HwasState hwasState = target->getAttr<ATTR_HWAS_STATE>();
- hwasState.deconfiguredByPlid = 0;
+ hwasState.deconfiguredByEid = 0;
hwasState.poweredOn = false;
hwasState.present = false;
hwasState.functional = false;
@@ -202,7 +202,7 @@ errlHndl_t discoverTargets()
bool chipPresent = true;
bool chipFunctional = true;
- uint32_t errlPlid = 0;
+ uint32_t errlEid = 0;
uint16_t pgData[VPD_CP00_PG_DATA_LENGTH / sizeof(uint16_t)];
bzero(pgData, sizeof(pgData));
@@ -213,10 +213,10 @@ errlHndl_t discoverTargets()
if (errl)
{ // read of ID/EC failed even tho we were present..
- HWAS_INF("pTarget %.8X - read IDEC failed (plid 0x%X) - bad",
- errl->plid(), pTarget->getAttr<ATTR_HUID>());
+ HWAS_INF("pTarget %.8X - read IDEC failed (eid 0x%X) - bad",
+ errl->eid(), pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -229,10 +229,10 @@ errlHndl_t discoverTargets()
if (errl)
{ // read of PG failed even tho we were present..
- HWAS_INF("pTarget %.8X - read PG failed (plid 0x%X)- bad",
- errl->plid(), pTarget->getAttr<ATTR_HUID>());
+ HWAS_INF("pTarget %.8X - read PG failed (eid 0x%X)- bad",
+ errl->eid(), pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -283,7 +283,7 @@ errlHndl_t discoverTargets()
HWAS_INF("pTarget %.8X - read PR failed - bad",
pTarget->getAttr<ATTR_HUID>());
chipFunctional = false;
- errlPlid = errl->plid();
+ errlEid = errl->eid();
// commit the error but keep going
errlCommit(errl, HWAS_COMP_ID);
@@ -411,7 +411,7 @@ errlHndl_t discoverTargets()
// for sub-parts, if it's not functional, it's not present.
enableHwasState(pDesc, descFunctional, descFunctional,
- errlPlid);
+ errlEid);
HWAS_DBG("pDesc %.8X - marked %spresent, %sfunctional",
pDesc->getAttr<ATTR_HUID>(),
descFunctional ? "" : "NOT ",
@@ -419,7 +419,7 @@ errlHndl_t discoverTargets()
}
// set HWAS state to show CHIP is present, functional per above
- enableHwasState(pTarget, chipPresent, chipFunctional, errlPlid);
+ enableHwasState(pTarget, chipPresent, chipFunctional, errlEid);
} // for pTarget_it
@@ -689,8 +689,7 @@ errlHndl_t checkMinimumHardware()
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
// if not, set the common plid
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
// finally, commit the log.
errlCommit(l_errl, HWAS_COMP_ID);
@@ -731,8 +730,7 @@ errlHndl_t checkMinimumHardware()
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
// if not, set the common plid
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
errlCommit(l_errl, HWAS_COMP_ID);
// errl is now NULL
@@ -777,8 +775,7 @@ errlHndl_t checkMinimumHardware()
EPUB_PRC_FIND_DECONFIGURED_PART,
SRCI_PRIORITY_HIGH );
// if we already have an error, link this one to the earlier plid.
- hwasErrorUpdatePlid( l_errl,
- l_commonPlid );
+ hwasErrorUpdatePlid( l_errl, l_commonPlid );
}
}
while (0);
OpenPOWER on IntegriCloud